@@ -14,9 +14,8 @@
     Library General Public License for more details.
 
     You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    along with this library; see the file COPYING.LIB.  If not, see
+    <http://www.gnu.org/licenses/>.
 */
 #ifndef CODEMODEL_UTILS_H
 #define CODEMODEL_UTILS_H
