@@ -47,6 +47,7 @@ namespace Icon_Utils {
     {
         it_Home = 0,
         it_Arrow,
+        it_File_Open,
         it_Folder,
         it_Folder_Cyan,
         it_Folder_Cyan_Open,
@@ -93,6 +94,8 @@ namespace Icon_Utils {
         it_Node,
         it_Artifact,
         it_Interface,
+        it_Interface_Provider,
+        it_Interface_Requirement,
         it_Datatype,
         it_Enum,
         it_Entity,
@@ -231,6 +234,8 @@ namespace Icon_Utils {
         it_Document_Edit,
         it_ClassOrPackage,
         it_Instance,
+        it_Remove,
+        it_Duplicate,
         N_ICONTYPES    // must remain last
     };
 
